"""Combined coach model."""

from typing import Any

from ..coach_model import CoachModel
from ..field_type import FFILL_KEY
from .null_check import is_null


def create_combined_coach_model(
    coach_models: list[CoachModel],
    identifier: str,
    coach_ffill: dict[str, dict[str, Any]],
) -> CoachModel:
    """Create a coach model by combining many coach models."""
    name = None
    birth_date = None
    age = None
    for coach_model in coach_models:
        coach_model_name = coach_model.name
        if not is_null(coach_model_name):
            name = coach_model_name
        coach_model_birthdate = coach_model.birth_date
        if not is_null(coach_model_birthdate):
            birth_date = coach_model_birthdate
        coach_model_age = coach_model.age
        if not is_null(coach_model_age):
            age = coach_model_age
    if name is None:
        raise ValueError("name is null.")
    coach_model = CoachModel(
        identifier=identifier,
        name=name,
        birth_date=birth_date,
        age=age,
    )

    coach_instance_ffill = coach_ffill.get(identifier, {})
    for field_name, field in coach_model.model_fields.items():
        extra = field.json_schema_extra or {}
        if extra.get(FFILL_KEY, False):  # type: ignore
            current_value = getattr(coach_model, field_name)
            if current_value is None:
                setattr(coach_model, field_name, coach_instance_ffill.get(field_name))
            else:
                coach_instance_ffill[field_name] = current_value
    coach_ffill[identifier] = coach_instance_ffill

    return coach_model



"""The enumeration of the different supported positions."""

from enum import StrEnum


class Position(StrEnum):
    """An enumeration over the different positions."""

    LINE_BACKER = "LB"
    DEFENSIVE_TACKLE = "DT"
    QUARTER_BACK = "QB"
    DEFENSIVE_LINESMAN = "DL"
    OFFENSIVE_LINESMAN = "OL"
    SAFETY = "S"
    WIDE_RECEIVER = "WR"
    GUARD = "G"
    RUNNING_BACK = "RB"
    TIGHT_END = "TE"
    OFFENSIVE_TACKLE = "OT"



"""NBA ESPN league model."""

from ....proxy_session import ProxySession
from ...espn.espn_league_model import ESPNLeagueModel
from ...league import League
from ..position import Position

_SEASON_URL = (
    "http://sports.core.api.espn.com/v2/sports/basketball/leagues/nba/seasons?limit=100"
)


class NBAESPNLeagueModel(ESPNLeagueModel):
    """NBA ESPN implementation of the league model."""

    def __init__(self, session: ProxySession, position: int | None = None) -> None:
        super().__init__(_SEASON_URL, League.NBA, session, position=position)

    @classmethod
    def name(cls) -> str:
        return "nba-espn-league-model"

    @classmethod
    def position_validator(cls) -> dict[str, str]:
        return {str(x): str(x) for x in Position}
